@@ -115,31 +115,31 @@ class Panda(QtGui.QMainWindow):
 		else:
 			self.ui.actionEnable_FM_Radio.setText(QtGui.QApplication.translate("pyRadio", "Enable FM Tx", None, QtGui.QApplication.UnicodeUTF8))
 			
-			QtCore.QObject.connect(self.ui.listStations, QtCore.SIGNAL('activated(int)'), self.playStation)
-			QtCore.QObject.connect(self.ui.btnNext, QtCore.SIGNAL('pressed()'), self.nextDown)
-			QtCore.QObject.connect(self.ui.btnNext, QtCore.SIGNAL('released()'), self.nextUp)
-			QtCore.QObject.connect(self.ui.btnHate, QtCore.SIGNAL('pressed()'), self.hateDown)
-			QtCore.QObject.connect(self.ui.btnHate, QtCore.SIGNAL('released()'), self.hateUp)
-			QtCore.QObject.connect(self.ui.btnNext, QtCore.SIGNAL('clicked()'), self.skipSong)
-			QtCore.QObject.connect(self.ui.btnHate, QtCore.SIGNAL('clicked()'), self.doHate)
-			QtCore.QObject.connect(self.ui.btnPlay, QtCore.SIGNAL('clicked()'), self.doPlayPause)
-			QtCore.QObject.connect(self.ui.btnLove, QtCore.SIGNAL('clicked()'), self.doLove)
-			QtCore.QObject.connect(self.ui.btnSleep, QtCore.SIGNAL('clicked()'), self.tiredSong)
-			QtCore.QObject.connect(self.player,QtCore.SIGNAL("PlayNext"), self.playNextSong)
-			QtCore.QObject.connect(self.player,QtCore.SIGNAL("LoveHate"), self.sigLoveHate)
-			QtCore.QObject.connect(self.player,QtCore.SIGNAL("stations"), self.getStations)
-			QtCore.QObject.connect(self.player,QtCore.SIGNAL("deleted"), self.stationDeleted)
-			QtCore.QObject.connect(self.player,QtCore.SIGNAL("tired"), self.sigTired)
-			QtCore.QObject.connect(self.player,QtCore.SIGNAL("authSuccess"), self.sigAuth)
-			QtCore.QObject.connect(self.player,QtCore.SIGNAL("authFail"), self.sigAuth)
-			QtCore.QObject.connect(self.player,QtCore.SIGNAL("stationCreated"), self.stationCreated)
-			QtCore.QObject.connect(self.s, QtCore.SIGNAL('shutdown'), self.sQuit)
-			QtCore.QObject.connect(self.ui.actionUser_Pass, QtCore.SIGNAL('triggered()'), self.setUserPass)
-			QtCore.QObject.connect(self.ui.actionDelete, QtCore.SIGNAL('triggered()'), self.deleteStation)
-			QtCore.QObject.connect(self.ui.actionEnable_FM_Radio, QtCore.SIGNAL('triggered()'), self.doFM)
-			QtCore.QObject.connect(self.ui.actionSnooze, QtCore.SIGNAL('triggered()'), self.setSnooze)
-			QtCore.QObject.connect(self.ui.actionCreate, QtCore.SIGNAL('triggered()'), self.createStation)
-			QtCore.QObject.connect(self.ui.actionDonate, QtCore.SIGNAL('triggered()'), self.open_donate)
+		QtCore.QObject.connect(self.ui.listStations, QtCore.SIGNAL('activated(int)'), self.playStation)
+		QtCore.QObject.connect(self.ui.btnNext, QtCore.SIGNAL('pressed()'), self.nextDown)
+		QtCore.QObject.connect(self.ui.btnNext, QtCore.SIGNAL('released()'), self.nextUp)
+		QtCore.QObject.connect(self.ui.btnHate, QtCore.SIGNAL('pressed()'), self.hateDown)
+		QtCore.QObject.connect(self.ui.btnHate, QtCore.SIGNAL('released()'), self.hateUp)
+		QtCore.QObject.connect(self.ui.btnNext, QtCore.SIGNAL('clicked()'), self.skipSong)
+		QtCore.QObject.connect(self.ui.btnHate, QtCore.SIGNAL('clicked()'), self.doHate)
+		QtCore.QObject.connect(self.ui.btnPlay, QtCore.SIGNAL('clicked()'), self.doPlayPause)
+		QtCore.QObject.connect(self.ui.btnLove, QtCore.SIGNAL('clicked()'), self.doLove)
+		QtCore.QObject.connect(self.ui.btnSleep, QtCore.SIGNAL('clicked()'), self.tiredSong)
+		QtCore.QObject.connect(self.player,QtCore.SIGNAL("PlayNext"), self.playNextSong)
+		QtCore.QObject.connect(self.player,QtCore.SIGNAL("LoveHate"), self.sigLoveHate)
+		QtCore.QObject.connect(self.player,QtCore.SIGNAL("stations"), self.getStations)
+		QtCore.QObject.connect(self.player,QtCore.SIGNAL("deleted"), self.stationDeleted)
+		QtCore.QObject.connect(self.player,QtCore.SIGNAL("tired"), self.sigTired)
+		QtCore.QObject.connect(self.player,QtCore.SIGNAL("authSuccess"), self.sigAuth)
+		QtCore.QObject.connect(self.player,QtCore.SIGNAL("authFail"), self.sigAuth)
+		QtCore.QObject.connect(self.player,QtCore.SIGNAL("stationCreated"), self.stationCreated)
+		QtCore.QObject.connect(self.s, QtCore.SIGNAL('shutdown'), self.sQuit)
+		QtCore.QObject.connect(self.ui.actionUser_Pass, QtCore.SIGNAL('triggered()'), self.setUserPass)
+		QtCore.QObject.connect(self.ui.actionDelete, QtCore.SIGNAL('triggered()'), self.deleteStation)
+		QtCore.QObject.connect(self.ui.actionEnable_FM_Radio, QtCore.SIGNAL('triggered()'), self.doFM)
+		QtCore.QObject.connect(self.ui.actionSnooze, QtCore.SIGNAL('triggered()'), self.setSnooze)
+		QtCore.QObject.connect(self.ui.actionCreate, QtCore.SIGNAL('triggered()'), self.createStation)
+		QtCore.QObject.connect(self.ui.actionDonate, QtCore.SIGNAL('triggered()'), self.open_donate)
 
 	def open_donate( self ):
 		self.d = QDialog(self)
@@ -327,6 +327,7 @@ class Panda(QtGui.QMainWindow):
 			f.close()
 
 	def getStations( self ):	
+		self.count = 0
 		self.ui.listStations.clear()
 		self.ui.btnPlay.setEnabled( True )
 		self.ui.listStations.setEnabled( True )
@@ -367,8 +368,9 @@ class Panda(QtGui.QMainWindow):
 		self.player.startPlay = 1
 		art = next[1]["art"]
 		self.ui.albumArt.setHtml("<img style='width: 100%; height: 95%' src='"+art+"'>")
-		self.setWindowTitle(QtGui.QApplication.translate("pyRadio", "\"" + next[1]["title"] + "\"" + " by " + next[1]["artist"] + " - pyRadio", None, QtGui.QApplication.UnicodeUTF8))
-		self.ui.lblAlbum.setText("on: " + next[1]["album"])
+		self.ui.lblAlbum.setText("\"" + next[1]["title"] + "\"" + " by " + next[1]["artist"] + "\n" + "on: " + next[1]["album"])
+		#self.setWindowTitle(QtGui.QApplication.translate("pyRadio", "\"" + next[1]["title"] + "\"" + " by " + next[1]["artist"] + " - pyRadio", None, QtGui.QApplication.UnicodeUTF8))
+		#self.ui.lblAlbum.setText("on: " + next[1]["album"])
 		if next[1]["rating"] > 0:
 			self.ui.btnLove.setStyleSheet("background-color: "+ self.c.color + ";\n"
 			"border: rgb(0, 0, 0);\nbackground-image: url(:/img/img/Thumbs-up-right-trans.png);")
